@@ -27,7 +27,12 @@ from vantage6.common import (
     warning, error, info, debug,
     bytes_to_base64s, check_config_write_permissions
 )
-from vantage6.common.globals import (STRING_ENCODING, APPNAME)
+from vantage6.common.globals import (
+    STRING_ENCODING,
+    APPNAME,
+    DEFAULT_DOCKER_REGISTRY,
+    DEFAULT_NODE_IMAGE
+)
 from vantage6.common.docker_addons import pull_if_newer
 from vantage6.client import Client
 from vantage6.client.encryption import RSACryptor
@@ -217,10 +222,12 @@ help_ = {
 @click.option('-i', '--image', default=None, help="Node Docker image to use")
 @click.option('--keep/--auto-remove', default=False,
               help="Keep image after finishing")
+@click.option('--attach/--detach', default=False,
+              help="Attach node logs to the console after start")
 @click.option('--mount-src', default='',
               help="mount vantage6-master package source")
 def cli_node_start(name, config, environment, system_folders, image, keep,
-                   mount_src):
+                   mount_src, attach):
     """Start the node instance.
 
         If no name or config is specified the default.yaml configuation is
@@ -277,10 +284,13 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
     ctx.data_dir.mkdir(parents=True, exist_ok=True)
     ctx.log_dir.mkdir(parents=True, exist_ok=True)
 
-    if image is None:
+    # Determine image-name. First we check if the option --image has been used.
+    # Then we check if the image has been specified in the config file, and
+    # finally we use the default settings from the package.
+    if not image:
         image = ctx.config.get(
             "image",
-            "harbor.vantage6.ai/infrastructure/node:latest"
+            f"{DEFAULT_DOCKER_REGISTRY}/{DEFAULT_NODE_IMAGE}"
         )
 
     info(f"Pulling latest node image '{image}'")
@@ -298,19 +308,18 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
         f"{ctx.docker_container_name}-vol")
 
     info("Creating file & folder mounts")
-    # FIXME: should only mount /mnt/database.csv if it is a file!
     # FIXME: should obtain mount points from DockerNodeContext
     mounts = [
         # (target, source)
-        ("/mnt/database.csv", str(ctx.databases["default"])),
         ("/mnt/log", str(ctx.log_dir)),
         ("/mnt/data", data_volume.name),
         ("/mnt/config", str(ctx.config_dir)),
         ("/var/run/docker.sock", "/var/run/docker.sock"),
     ]
 
+
     if mount_src:
-        # If mount_src is a relative path, docker willl consider it a volume.
+        # If mount_src is a relative path, docker will consider it a volume.
         mount_src = os.path.abspath(mount_src)
         mounts.append(('/vantage6', mount_src))
 
@@ -336,23 +345,34 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
             warning(f"private key file provided {fullpath}, "
                     "but does not exists")
 
-    volumes = {}
-    for mount in mounts:
-        volumes[mount[1]] = {'bind': mount[0], 'mode': 'rw'}
-
     # Be careful not to use 'environment' as it would override the function
     # argument ;-).
     env = {
         "DATA_VOLUME_NAME": data_volume.name,
-        "DATABASE_URI": "/mnt/database.csv",
         "PRIVATE_KEY": "/mnt/private_key.pem"
     }
 
+    # only mount the DB if it is a file
+    info("Setting up database")
+    db_is_file = Path(ctx.databases["default"]).exists()
+    env['DATABASE_URI'] = "/mnt/database.csv" if db_is_file else \
+        ctx.databases['default']
+    info(f" - URI: {env['DATABASE_URI']}")
+    if db_is_file:
+        mounts.append(("/mnt/database.csv", str(ctx.databases["default"])))
+    else:
+        warning(' - Are you using a non file-based database?')
+        warning('   Or did you make a mistake in the database path?')
+
     system_folders_option = "--system" if system_folders else "--user"
     cmd = f'vnode-local start -c /mnt/config/{name}.yaml -n {name} -e '\
           f'{environment} --dockerized {system_folders_option}'
 
     info(f"Runing Docker container")
+    volumes = {}
+    for mount in mounts:
+        volumes[mount[1]] = {'bind': mount[0], 'mode': 'rw'}
+
     # debug(f"  with command: '{cmd}'")
     # debug(f"  with mounts: {volumes}")
     # debug(f"  with environment: {env}")
@@ -375,6 +395,15 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
 
     info(f"Success! container id = {container}")
 
+    if attach:
+        logs = container.attach(stream=True, logs=True)
+        Thread(target=print_log_worker, args=(logs,), daemon=True).start()
+        while True:
+            try:
+                time.sleep(1)
+            except KeyboardInterrupt:
+                info("Closing log file. Keyboard Interrupt.")
+                exit(0)
 
 #
 #   stop
